"""
    EMIL AccountingService

    The EMIL AccountingService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from eis.accounting.api_client import ApiClient, Endpoint as _Endpoint
from eis.accounting.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from eis.accounting.model.create_booking_entry_request_dto import CreateBookingEntryRequestDto
from eis.accounting.model.create_booking_entry_response_class import CreateBookingEntryResponseClass
from eis.accounting.model.get_booking_entry_response_class import GetBookingEntryResponseClass
from eis.accounting.model.list_booking_entries_response_class import ListBookingEntriesResponseClass


class BookingEntriesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.create_booking_entry_endpoint = _Endpoint(
            settings={
                'response_type': (CreateBookingEntryResponseClass,),
                'auth': [
                    'bearer'
                ],
                'endpoint_path': '/accountingservice/v1/booking-entries',
                'operation_id': 'create_booking_entry',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'create_booking_entry_request_dto',
                    'authorization',
                ],
                'required': [
                    'create_booking_entry_request_dto',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'create_booking_entry_request_dto':
                        (CreateBookingEntryRequestDto,),
                    'authorization':
                        (str,),
                },
                'attribute_map': {
                    'authorization': 'Authorization',
                },
                'location_map': {
                    'create_booking_entry_request_dto': 'body',
                    'authorization': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.get_booking_entry_endpoint = _Endpoint(
            settings={
                'response_type': (GetBookingEntryResponseClass,),
                'auth': [
                    'bearer'
                ],
                'endpoint_path': '/accountingservice/v1/booking-entries/{code}',
                'operation_id': 'get_booking_entry',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'code',
                    'expand',
                    'authorization',
                ],
                'required': [
                    'code',
                    'expand',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'code':
                        (str,),
                    'expand':
                        (str,),
                    'authorization':
                        (str,),
                },
                'attribute_map': {
                    'code': 'code',
                    'expand': 'expand',
                    'authorization': 'Authorization',
                },
                'location_map': {
                    'code': 'path',
                    'expand': 'query',
                    'authorization': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.list_booking_entries_endpoint = _Endpoint(
            settings={
                'response_type': (ListBookingEntriesResponseClass,),
                'auth': [
                    'bearer'
                ],
                'endpoint_path': '/accountingservice/v1/booking-entries',
                'operation_id': 'list_booking_entries',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'authorization',
                    'page_size',
                    'page_token',
                    'filter',
                    'search',
                    'order',
                    'expand',
                    'filters',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'authorization':
                        (str,),
                    'page_size':
                        (float,),
                    'page_token':
                        (str,),
                    'filter':
                        (str,),
                    'search':
                        (str,),
                    'order':
                        (str,),
                    'expand':
                        (str,),
                    'filters':
                        (str,),
                },
                'attribute_map': {
                    'authorization': 'Authorization',
                    'page_size': 'pageSize',
                    'page_token': 'pageToken',
                    'filter': 'filter',
                    'search': 'search',
                    'order': 'order',
                    'expand': 'expand',
                    'filters': 'filters',
                },
                'location_map': {
                    'authorization': 'header',
                    'page_size': 'query',
                    'page_token': 'query',
                    'filter': 'query',
                    'search': 'query',
                    'order': 'query',
                    'expand': 'query',
                    'filters': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def create_booking_entry(
        self,
        create_booking_entry_request_dto,
        **kwargs
    ):
        """Create the booking entry  # noqa: E501

        This endpoint creates a new booking entry.  **Required Permissions**  \"accounting-management.entries.create\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_booking_entry(create_booking_entry_request_dto, async_req=True)
        >>> result = thread.get()

        Args:
            create_booking_entry_request_dto (CreateBookingEntryRequestDto):

        Keyword Args:
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            CreateBookingEntryResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['create_booking_entry_request_dto'] = \
            create_booking_entry_request_dto
        return self.create_booking_entry_endpoint.call_with_http_info(**kwargs)

    def get_booking_entry(
        self,
        code,
        expand,
        **kwargs
    ):
        """Retrieve the booking entry  # noqa: E501

        This endpoint gets a booking entry.  **Required Permissions**  \"accounting-management.entries.view\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_booking_entry(code, expand, async_req=True)
        >>> result = thread.get()

        Args:
            code (str):
            expand (str):

        Keyword Args:
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            GetBookingEntryResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['code'] = \
            code
        kwargs['expand'] = \
            expand
        return self.get_booking_entry_endpoint.call_with_http_info(**kwargs)

    def list_booking_entries(
        self,
        **kwargs
    ):
        """List booking entries  # noqa: E501

        This endpoint gets booking entries.  **Required Permissions**  \"accounting-management.entries.view\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_booking_entries(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            page_size (float): A limit on the number of objects to be returned.     Limit ranges between 1 and 50. Default: 10.. [optional]
            page_token (str): A cursor for use in pagination.     pageToken is an ID that defines your place in the list.     For instance, if you make a list request and receive 100 objects and pageToken=1, your subsequent call can include pageToken=2 in order to fetch the next page of the list.. [optional]
            filter (str): Filter the response by one or multiple fields.     In general, fetching filtered responses will conserve bandwidth and reduce response time.. [optional]
            search (str): To search the list by any field, pass search=xxx to fetch the result.. [optional]
            order (str): The order parameter determines how the results should be sorted according to a specified field.     It functions similarly to an SQL ORDER BY.     Sorting can be performed in either ascending (ASC) or descending (DESC) order.     Default: ASC.. [optional]
            expand (str): Use this parameter to fetch additional information about the list items.     The expand query parameter increases the set of fields that appear in the response in addition to the default ones.     Expanding resources can reduce the number of API calls required to accomplish a task.     However, use this with parsimony as some expanded fields can drastically increase payload size.. [optional]
            filters (str): Filters the response by one or multiple fields.          Advanced filter functionality allows you to perform more complex filtering operations.          In general, fetching filtered responses conserves bandwidth and reduces response time.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ListBookingEntriesResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.list_booking_entries_endpoint.call_with_http_info(**kwargs)




"""
    EMIL AccountingService

    The EMIL AccountingService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.accounting
from eis.accounting.api.number_ranges_api import NumberRangesApi  # noqa: E501


class TestNumberRangesApi(unittest.TestCase):
    """NumberRangesApi unit test stubs"""

    def setUp(self):
        self.api = NumberRangesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_number_range(self):
        """Test case for create_number_range

        Create the Number Range  # noqa: E501
        """
        pass

    def test_delete_number_range(self):
        """Test case for delete_number_range

        Delete the Personal Account  # noqa: E501
        """
        pass

    def test_get_number_range(self):
        """Test case for get_number_range

        Retrieve the Financial Account  # noqa: E501
        """
        pass

    def test_list_number_ranges(self):
        """Test case for list_number_ranges

        List Financial Accounts  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from eis.accounting.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from eis.accounting.model.booking_entry_class import BookingEntryClass
from eis.accounting.model.create_booking_entry_request_dto import CreateBookingEntryRequestDto
from eis.accounting.model.create_booking_entry_response_class import CreateBookingEntryResponseClass
from eis.accounting.model.create_financial_account_request_dto import CreateFinancialAccountRequestDto
from eis.accounting.model.create_financial_account_response_class import CreateFinancialAccountResponseClass
from eis.accounting.model.create_number_range_request_dto import CreateNumberRangeRequestDto
from eis.accounting.model.create_number_range_response_class import CreateNumberRangeResponseClass
from eis.accounting.model.create_personal_account_request_dto import CreatePersonalAccountRequestDto
from eis.accounting.model.create_personal_account_response_class import CreatePersonalAccountResponseClass
from eis.accounting.model.financial_account_class import FinancialAccountClass
from eis.accounting.model.financial_transaction_class import FinancialTransactionClass
from eis.accounting.model.financial_transaction_data_dto import FinancialTransactionDataDto
from eis.accounting.model.get_booking_entry_response_class import GetBookingEntryResponseClass
from eis.accounting.model.get_financial_account_response_class import GetFinancialAccountResponseClass
from eis.accounting.model.get_financial_transaction_response_class import GetFinancialTransactionResponseClass
from eis.accounting.model.get_number_range_response_class import GetNumberRangeResponseClass
from eis.accounting.model.get_personal_account_response_class import GetPersonalAccountResponseClass
from eis.accounting.model.inline_response200 import InlineResponse200
from eis.accounting.model.inline_response503 import InlineResponse503
from eis.accounting.model.list_booking_entries_response_class import ListBookingEntriesResponseClass
from eis.accounting.model.list_financial_accounts_response_class import ListFinancialAccountsResponseClass
from eis.accounting.model.list_financial_transactions_response_class import ListFinancialTransactionsResponseClass
from eis.accounting.model.list_number_range_response_class import ListNumberRangeResponseClass
from eis.accounting.model.list_personal_accounts_response_class import ListPersonalAccountsResponseClass
from eis.accounting.model.number_range_class import NumberRangeClass
from eis.accounting.model.personal_account_class import PersonalAccountClass



"""
    EMIL AccountingService

    The EMIL AccountingService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.accounting
from eis.accounting.api.booking_entries_api import BookingEntriesApi  # noqa: E501


class TestBookingEntriesApi(unittest.TestCase):
    """BookingEntriesApi unit test stubs"""

    def setUp(self):
        self.api = BookingEntriesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_booking_entry(self):
        """Test case for create_booking_entry

        Create the booking entry  # noqa: E501
        """
        pass

    def test_get_booking_entry(self):
        """Test case for get_booking_entry

        Retrieve the booking entry  # noqa: E501
        """
        pass

    def test_list_booking_entries(self):
        """Test case for list_booking_entries

        List booking entries  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
